@@ -17,14 +17,14 @@
 
 #@PydevCodeAnalysisIgnoren
 import os
-from pyface.qt import QtGui, QtCore 
-from PyQt4 import uic
-
+import sys
+sys.path.append(os.path.dirname(__file__))
 from subprocess import call
-from manager import SynVecRef
-os.environ['ETS_TOOLKIT'] = 'qt4'
 
+from neuron import h
+h.load_file("stdrun.hoc")
 
+# Logging
 import logging
 FORMAT = '%(levelname)s %(name)s %(lineno)s   %(message)s'
 if os.environ.has_key('DEBUG'):
@@ -33,32 +33,46 @@ else:
     logging.basicConfig(level=logging.INFO, format=FORMAT)
 logger = logging.getLogger(__name__)
 
-import sys
-sys.path.append(os.path.dirname(__file__)) 
+import matplotlib as mpl
+import matplotlib.backends
+if mpl.backends.backend is not "Qt4Agg":
+    msg = "Neuronvisio works only with the Qt4Agg backend." 
+    msg += " Your current backend is %s." %mpl.backends.backend
+    msg += " Please change it to Qt4Agg following the instruction at "
+    msg += "http://neuronvisio.org/gettingstarted.html#picking-the-right-backend"
+    
+    logger.error(msg)
+elif mpl.backends.backend == None:
+    mpl.use('Qt4Agg')
+mpl.interactive(True)
+
+import numpy as np
+
+os.environ['ETS_TOOLKIT'] = 'qt4'
+from pyface.qt import QtGui, QtCore 
+from PyQt4 import uic
 
 if os.name != 'nt':
     from PyQt4 import QtGui, QtCore, uic
 
 from PyQt4.QtCore import Qt
-import numpy as np
 
-import matplotlib as mpl
-if mpl.backends.backend is None: 
-    mpl.use('Qt4Agg')
-mpl.interactive(True)
 
-from neuron import h
-h.load_file("stdrun.hoc")
 
 # Visio
 
 from visio import Visio
 import manager
 import res # icons
+from manager import SynVecRef
 
 # ModelDb
 from modeldb.ModelDB import Models
 
+class ExtensionNotRecognised(Exception):
+    pass
+
+
 class Controls(object):
     """Main class Neuronvisio"""
     def __init__(self):
@@ -333,19 +347,42 @@ class Controls(object):
             pass
 
     def load(self, path_to_file=None):
-        """General loading method. It loads either an hoc file or 
-        a hdf5 file. The file type is recognised on the extension"""
+        """
+        General loading method for any kind of format.
+        Extensions recognised:
+        .xml - NeuroML
+        .hoc - NEURON hoc file
+        .h5 - HDF file formatted according to Neuronvisio format.
+        The file type is recognised using the extension.
+        """
         if path_to_file == None:
             filename = QtGui.QFileDialog.getOpenFileName()
             if filename:
                 path_to_file = str(filename)
         
         base_name, file_extension = os.path.splitext(path_to_file)
-        if (file_extension == '.hoc'):
-            file_path, hoc_file = os.path.split(path_to_file)
-            self.load_hoc_model(file_path, hoc_file)
-        else:
-            self.load_hdf(path_to_file)
+        try:
+            if (file_extension == '.hoc'):
+                file_path, hoc_file = os.path.split(path_to_file)
+                self.load_hoc_model(file_path, hoc_file)
+            elif (file_extension == ".xml"):
+                self.manager.load_neuroml(path_to_file)
+            elif (file_extension == ".h5"):
+                self.load_hdf(path_to_file)
+            else:
+                raise ExtensionNotRecognised
+        except ExtensionNotRecognised:
+        
+            msg= """
+            File extension not recognised!! 
+            Neuronvisio was not able to recognise the file extension. 
+            Extensions recognised:
+                    .xml - NeuroML
+                    .hoc - NEURON hoc file
+                    .h5 - HDF file formatted according to Neuronvisio format.
+                    """
+            logger.error(msg)
+            
 
     def load_hdf(self, path_to_hdf):
     
@@ -584,8 +621,8 @@ class Controls(object):
         if len (self.manager.groups['t']) == time_point_indx:
             time_point_indx = time_point_indx - 1 # Avoid to go out of scale
         time = self.manager.groups['t'][time_point_indx]
-        self.ui.animationTime.setText(str(time))
-        
+        time_point_string = "%.3f" %round(time, 3)
+        self.ui.animationTime.setText(time_point_string)
         
         start_value = float(self.ui.startValue.text())
         end_value = float(self.ui.endValue.text())
